@@ -37,15 +37,17 @@ package OP::Float;
 use strict;
 use warnings;
 
-use Perl6::Subs;
-
 use OP::Enum::Bool;
 
 use base qw| OP::Num Data::Float |;
 
 use overload fallback => true, %OP::Num::overload;
 
-method assert(OP::Class $class: *@rules) {
+# method assert(OP::Class $class: *@rules) {
+sub assert {
+  my $class = shift;
+  my @rules = @_;
+
   my %parsed = OP::Type::__parseTypeArgs(
     OP::Type::isFloat, @rules
   );
@@ -56,4 +58,4 @@ method assert(OP::Class $class: *@rules) {
   return $class->__assertClass()->new(%parsed);
 }
 
-1;
+true;
