@@ -15,7 +15,6 @@ use warnings;
 
 use OP::Class qw| true false |;
 use OP::Num;
-use Perl6::Subs;
 
 use Time::Seconds;
 
@@ -25,7 +24,11 @@ use overload fallback => true,
   '<=>' => '_compare',
   %OP::Num::overload;
 
-method assert(OP::Class $class: *@rules) {
+# method assert(OP::Class $class: *@rules) {
+sub assert {
+  my $class = shift;
+  my @rules = @_;
+
   my %parsed = OP::Type::__parseTypeArgs(
     sub {
       UNIVERSAL::isa($_[0], "DateTime")
